pub struct DetailRequest {
pub id: String,
pub unbounded: bool,
}Fields
id: Stringunbounded: boolTrait Implementations
Sourceimpl Clone for DetailRequest
impl Clone for DetailRequest
Sourceimpl Debug for DetailRequest
impl Debug for DetailRequest
Sourceimpl<'de> Deserialize<'de> for DetailRequest
impl<'de> Deserialize<'de> for DetailRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DetailRequest
impl JsonSchema for DetailRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DetailRequest
impl RefUnwindSafe for DetailRequest
impl Send for DetailRequest
impl Sync for DetailRequest
impl Unpin for DetailRequest
impl UnsafeUnpin for DetailRequest
impl UnwindSafe for DetailRequest