pub struct DiffRequest {
pub from: i64,
pub to: i64,
}Fields
from: i64to: i64Trait Implementations
Sourceimpl Clone for DiffRequest
impl Clone for DiffRequest
Sourceimpl Debug for DiffRequest
impl Debug for DiffRequest
Sourceimpl<'de> Deserialize<'de> for DiffRequest
impl<'de> Deserialize<'de> for DiffRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DiffRequest
impl JsonSchema for DiffRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DiffRequest
impl RefUnwindSafe for DiffRequest
impl Send for DiffRequest
impl Sync for DiffRequest
impl Unpin for DiffRequest
impl UnsafeUnpin for DiffRequest
impl UnwindSafe for DiffRequest