pub struct ExportRequest {
pub format: String,
}Fields
format: StringTrait Implementations
Sourceimpl Clone for ExportRequest
impl Clone for ExportRequest
Sourceimpl Debug for ExportRequest
impl Debug for ExportRequest
Sourceimpl<'de> Deserialize<'de> for ExportRequest
impl<'de> Deserialize<'de> for ExportRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExportRequest
impl JsonSchema for ExportRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExportRequest
impl RefUnwindSafe for ExportRequest
impl Send for ExportRequest
impl Sync for ExportRequest
impl Unpin for ExportRequest
impl UnsafeUnpin for ExportRequest
impl UnwindSafe for ExportRequest