pub struct ImpactRequest {
pub files: Vec<String>,
pub symbols: Vec<String>,
pub diff: Option<String>,
pub unbounded: bool,
}Fields
files: Vec<String>symbols: Vec<String>diff: Option<String>unbounded: boolTrait Implementations
Sourceimpl Clone for ImpactRequest
impl Clone for ImpactRequest
Sourceimpl Debug for ImpactRequest
impl Debug for ImpactRequest
Sourceimpl<'de> Deserialize<'de> for ImpactRequest
impl<'de> Deserialize<'de> for ImpactRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ImpactRequest
impl JsonSchema for ImpactRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ImpactRequest
impl RefUnwindSafe for ImpactRequest
impl Send for ImpactRequest
impl Sync for ImpactRequest
impl Unpin for ImpactRequest
impl UnsafeUnpin for ImpactRequest
impl UnwindSafe for ImpactRequest