pub struct IndexPathsRequest {
pub paths: Vec<String>,
pub quiet: bool,
}Fields
paths: Vec<String>quiet: boolTrait Implementations
Sourceimpl Clone for IndexPathsRequest
impl Clone for IndexPathsRequest
Sourceimpl Debug for IndexPathsRequest
impl Debug for IndexPathsRequest
Sourceimpl<'de> Deserialize<'de> for IndexPathsRequest
impl<'de> Deserialize<'de> for IndexPathsRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for IndexPathsRequest
impl JsonSchema for IndexPathsRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for IndexPathsRequest
impl RefUnwindSafe for IndexPathsRequest
impl Send for IndexPathsRequest
impl Sync for IndexPathsRequest
impl Unpin for IndexPathsRequest
impl UnsafeUnpin for IndexPathsRequest
impl UnwindSafe for IndexPathsRequest