pub struct QuotaEntry {
pub kind: String,
pub fraction: f64,
}Fields
kind: Stringfraction: f64Trait Implementations
Sourceimpl Clone for QuotaEntry
impl Clone for QuotaEntry
Sourceimpl Debug for QuotaEntry
impl Debug for QuotaEntry
Sourceimpl<'de> Deserialize<'de> for QuotaEntry
impl<'de> Deserialize<'de> for QuotaEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QuotaEntry
impl JsonSchema for QuotaEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for QuotaEntry
impl RefUnwindSafe for QuotaEntry
impl Send for QuotaEntry
impl Sync for QuotaEntry
impl Unpin for QuotaEntry
impl UnsafeUnpin for QuotaEntry
impl UnwindSafe for QuotaEntry