pub struct RankFeatures {
pub task_ppr: f64,
pub global_ppr: f64,
pub lexical: f64,
pub semantic: f64,
pub confidence: f64,
pub criticality: f64,
pub change_risk: f64,
pub novelty: f64,
}Fields
task_ppr: f64global_ppr: f64lexical: f64semantic: f64confidence: f64criticality: f64change_risk: f64novelty: f64Trait Implementations
Sourceimpl Clone for RankFeatures
impl Clone for RankFeatures
Sourceimpl Debug for RankFeatures
impl Debug for RankFeatures
Sourceimpl Default for RankFeatures
impl Default for RankFeatures
Sourceimpl<'de> Deserialize<'de> for RankFeatures
impl<'de> Deserialize<'de> for RankFeatures
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RankFeatures
impl JsonSchema for RankFeatures
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RankFeatures
impl RefUnwindSafe for RankFeatures
impl Send for RankFeatures
impl Sync for RankFeatures
impl Unpin for RankFeatures
impl UnsafeUnpin for RankFeatures
impl UnwindSafe for RankFeatures