pub struct RankItem {
pub id: String,
pub rank: f64,
pub position: usize,
pub features: RankFeatures,
pub specificity: f64,
pub reasons: Vec<String>,
pub plugin_features: BTreeMap<String, f64>,
}Fields
id: Stringrank: f64position: usizefeatures: RankFeaturesspecificity: f64reasons: Vec<String>plugin_features: BTreeMap<String, f64>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for RankItem
impl<'de> Deserialize<'de> for RankItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RankItem
impl JsonSchema for RankItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RankItem
impl RefUnwindSafe for RankItem
impl Send for RankItem
impl Sync for RankItem
impl Unpin for RankItem
impl UnsafeUnpin for RankItem
impl UnwindSafe for RankItem