pub struct RankRequest {
pub goal: Option<String>,
pub profile: Option<String>,
pub limit: usize,
pub explain: bool,
pub include_features: bool,
pub include_intermediate: bool,
}Fields
goal: Option<String>profile: Option<String>limit: usizeexplain: boolinclude_features: boolinclude_intermediate: boolTrait Implementations
Sourceimpl Clone for RankRequest
impl Clone for RankRequest
Sourceimpl Debug for RankRequest
impl Debug for RankRequest
Sourceimpl<'de> Deserialize<'de> for RankRequest
impl<'de> Deserialize<'de> for RankRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RankRequest
impl JsonSchema for RankRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RankRequest
impl RefUnwindSafe for RankRequest
impl Send for RankRequest
impl Sync for RankRequest
impl Unpin for RankRequest
impl UnsafeUnpin for RankRequest
impl UnwindSafe for RankRequest