pub struct RankedEntry {
pub id: String,
pub value: f64,
pub token_cost: usize,
pub kind: String,
pub group: Option<String>,
}Fields
id: Stringvalue: f64token_cost: usizekind: Stringgroup: Option<String>Trait Implementations
Sourceimpl Clone for RankedEntry
impl Clone for RankedEntry
Sourceimpl Debug for RankedEntry
impl Debug for RankedEntry
Sourceimpl<'de> Deserialize<'de> for RankedEntry
impl<'de> Deserialize<'de> for RankedEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RankedEntry
impl JsonSchema for RankedEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RankedEntry
impl RefUnwindSafe for RankedEntry
impl Send for RankedEntry
impl Sync for RankedEntry
impl Unpin for RankedEntry
impl UnsafeUnpin for RankedEntry
impl UnwindSafe for RankedEntry