pub struct SelectionRequest {
pub ranked: Vec<RankedEntry>,
pub budget: usize,
pub lambda: Option<f64>,
pub quotas: Option<Vec<QuotaEntry>>,
}Fields
ranked: Vec<RankedEntry>budget: usizelambda: Option<f64>quotas: Option<Vec<QuotaEntry>>Trait Implementations
Sourceimpl Clone for SelectionRequest
impl Clone for SelectionRequest
Sourceimpl Debug for SelectionRequest
impl Debug for SelectionRequest
Sourceimpl<'de> Deserialize<'de> for SelectionRequest
impl<'de> Deserialize<'de> for SelectionRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SelectionRequest
impl JsonSchema for SelectionRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SelectionRequest
impl RefUnwindSafe for SelectionRequest
impl Send for SelectionRequest
impl Sync for SelectionRequest
impl Unpin for SelectionRequest
impl UnsafeUnpin for SelectionRequest
impl UnwindSafe for SelectionRequest