pub struct SnapshotSaveRequest {
pub task: String,
pub budget: Option<usize>,
}Fields
task: Stringbudget: Option<usize>Trait Implementations
Sourceimpl Clone for SnapshotSaveRequest
impl Clone for SnapshotSaveRequest
Sourceimpl Debug for SnapshotSaveRequest
impl Debug for SnapshotSaveRequest
Sourceimpl<'de> Deserialize<'de> for SnapshotSaveRequest
impl<'de> Deserialize<'de> for SnapshotSaveRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SnapshotSaveRequest
impl JsonSchema for SnapshotSaveRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SnapshotSaveRequest
impl RefUnwindSafe for SnapshotSaveRequest
impl Send for SnapshotSaveRequest
impl Sync for SnapshotSaveRequest
impl Unpin for SnapshotSaveRequest
impl UnsafeUnpin for SnapshotSaveRequest
impl UnwindSafe for SnapshotSaveRequest