pub struct StartupRequest {
pub budget: Option<usize>,
}Fields
budget: Option<usize>Trait Implementations
Sourceimpl Clone for StartupRequest
impl Clone for StartupRequest
Sourceimpl Debug for StartupRequest
impl Debug for StartupRequest
Sourceimpl<'de> Deserialize<'de> for StartupRequest
impl<'de> Deserialize<'de> for StartupRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StartupRequest
impl JsonSchema for StartupRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StartupRequest
impl RefUnwindSafe for StartupRequest
impl Send for StartupRequest
impl Sync for StartupRequest
impl Unpin for StartupRequest
impl UnsafeUnpin for StartupRequest
impl UnwindSafe for StartupRequest