pub struct SurfaceStages {
pub lexical: bool,
pub global_ppr: bool,
pub task_ppr: bool,
pub mmr: bool,
pub quotas: bool,
pub optimizer: bool,
}Expand description
Per-stage toggles for surface.build (all default true).
Fields
lexical: boolglobal_ppr: booltask_ppr: boolmmr: boolquotas: booloptimizer: boolTrait Implementations
Sourceimpl Clone for SurfaceStages
impl Clone for SurfaceStages
Sourceimpl Debug for SurfaceStages
impl Debug for SurfaceStages
Sourceimpl Default for SurfaceStages
impl Default for SurfaceStages
Sourceimpl<'de> Deserialize<'de> for SurfaceStages
impl<'de> Deserialize<'de> for SurfaceStages
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SurfaceStages
impl JsonSchema for SurfaceStages
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SurfaceStages
impl RefUnwindSafe for SurfaceStages
impl Send for SurfaceStages
impl Sync for SurfaceStages
impl Unpin for SurfaceStages
impl UnsafeUnpin for SurfaceStages
impl UnwindSafe for SurfaceStages