pub struct SystemSurfaceMap {
pub repository: String,
pub revision: String,
pub epoch: String,
pub entries: Vec<SurfaceEntry>,
pub token_count: usize,
pub omitted: Vec<SurfaceOmission>,
}Expand description
The System Surface Map: the ranked actual-API layer of a repository, built from System IR (Level 1 of the context stack).
Fields
repository: Stringrevision: Stringepoch: Stringentries: Vec<SurfaceEntry>token_count: usizeomitted: Vec<SurfaceOmission>Trait Implementations
Sourceimpl Clone for SystemSurfaceMap
impl Clone for SystemSurfaceMap
Sourcefn clone(&self) -> SystemSurfaceMap
fn clone(&self) -> SystemSurfaceMap
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SystemSurfaceMap
impl Debug for SystemSurfaceMap
Sourceimpl<'de> Deserialize<'de> for SystemSurfaceMap
impl<'de> Deserialize<'de> for SystemSurfaceMap
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<SystemSurfaceMap, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SystemSurfaceMap, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SystemSurfaceMap
impl JsonSchema for SystemSurfaceMap
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SystemSurfaceMap
impl PartialEq for SystemSurfaceMap
Sourceimpl Serialize for SystemSurfaceMap
impl Serialize for SystemSurfaceMap
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for SystemSurfaceMap